@@ -13,8 +13,11 @@ build_time_vars = {'ABIFLAGS': '',
  'BINDIR': '/usr/bin',
  'BINLIBDEST': '/usr/lib/python3.9',
  'BLDLIBRARY': '-L. -lpython3.9',
- 'BLDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-              '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'BLDSHARED': 'gcc -shared -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+              '-Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs '
+              '-flto=auto -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+              '-Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs '
+              '-flto=auto',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'x86_64-pc-linux-gnu',
@@ -23,40 +26,47 @@ build_time_vars = {'ABIFLAGS': '',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
            '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
-           '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+           '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
            '-Werror=format-security         -fstack-clash-protection '
-           '-fcf-protection -g '
-           '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
-           '-fno-semantic-interposition -march=x86-64 -mtune=generic -O2 -pipe '
-           '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-           '-Werror=format-security         -fstack-clash-protection '
-           '-fcf-protection -g '
-           '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
-           '-fno-semantic-interposition -march=x86-64 -mtune=generic -O2 -pipe '
-           '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-           '-Werror=format-security         -fstack-clash-protection '
-           '-fcf-protection -g '
-           '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
-           '-fno-semantic-interposition',
+           '-fcf-protection         -fno-omit-frame-pointer '
+           '-mno-omit-leaf-frame-pointer -g '
+           '-ffile-prefix-map=/home/aurutils/.cache/aurutils/sync/python39/src=/usr/src/debug/python39 '
+           '-flto=auto -fno-semantic-interposition -march=x86-64 '
+           '-mtune=generic -O2 -pipe -fno-plt -fexceptions         '
+           '-Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         '
+           '-fstack-clash-protection -fcf-protection         '
+           '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g '
+           '-ffile-prefix-map=/home/aurutils/.cache/aurutils/sync/python39/src=/usr/src/debug/python39 '
+           '-flto=auto -fno-semantic-interposition -march=x86-64 '
+           '-mtune=generic -O2 -pipe -fno-plt -fexceptions         '
+           '-Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         '
+           '-fstack-clash-protection -fcf-protection         '
+           '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g '
+           '-ffile-prefix-map=/home/aurutils/.cache/aurutils/sync/python39/src=/usr/src/debug/python39 '
+           '-flto=auto -fno-semantic-interposition',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
-                     '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                     '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                      '-Werror=format-security         -fstack-clash-protection '
-                     '-fcf-protection -g '
-                     '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
-                     '-fno-semantic-interposition',
+                     '-fcf-protection         -fno-omit-frame-pointer '
+                     '-mno-omit-leaf-frame-pointer -g '
+                     '-ffile-prefix-map=/home/aurutils/.cache/aurutils/sync/python39/src=/usr/src/debug/python39 '
+                     '-flto=auto -fno-semantic-interposition',
  'CONFIGURE_CFLAGS_NODIST': '-flto -fuse-linker-plugin -ffat-lto-objects '
                             '-flto-partition=none -g -std=c99 -Wextra '
                             '-Wno-unused-result -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
+                            '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '',
- 'CONFIGURE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'CONFIGURE_LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+                      '-Wl,-z,now          -Wl,-z,pack-relative-relocs '
+                      '-flto=auto',
  'CONFIGURE_LDFLAGS_NODIST': '-flto -fuse-linker-plugin -ffat-lto-objects '
                              '-flto-partition=none -g',
  'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-computed-gotos' "
@@ -66,17 +76,19 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
                 "'--with-tzpath=/usr/share/zoneinfo' 'CFLAGS=-march=x86-64 "
                 '-mtune=generic -O2 -pipe -fno-plt -fexceptions         '
-                '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                 '-Werror=format-security         -fstack-clash-protection '
-                '-fcf-protection -g '
-                '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
-                "-fno-semantic-interposition' "
-                "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now'",
+                '-fcf-protection         -fno-omit-frame-pointer '
+                '-mno-omit-leaf-frame-pointer -g '
+                '-ffile-prefix-map=/home/aurutils/.cache/aurutils/sync/python39/src=/usr/src/debug/python39 '
+                "-flto=auto -fno-semantic-interposition' 'LDFLAGS=-Wl,-O1 "
+                '-Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+                "-Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python39/src/Python-3.9.19/coverage.info',
- 'COVERAGE_REPORT': '/build/python39/src/Python-3.9.19/lcov-report',
+ 'COVERAGE_INFO': '/home/aurutils/.cache/aurutils/sync/python39/src/Python-3.9.23/coverage.info',
+ 'COVERAGE_REPORT': '/home/aurutils/.cache/aurutils/sync/python39/src/Python-3.9.23/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include',
@@ -132,7 +144,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_BLUETOOTH_BLUETOOTH_H': 1,
  'HAVE_BLUETOOTH_H': 0,
  'HAVE_BROKEN_MBSTOWCS': 0,
- 'HAVE_BROKEN_NICE': 1,
+ 'HAVE_BROKEN_NICE': 0,
  'HAVE_BROKEN_PIPE_BUF': 0,
  'HAVE_BROKEN_POLL': 0,
  'HAVE_BROKEN_POSIX_SEMAPHORES': 0,
@@ -560,13 +572,18 @@ build_time_vars = {'ABIFLAGS': '',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -shared',
- 'LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-            '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+            '-Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto '
+            '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+            '-Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto',
  'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.9.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-             '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'LDSHARED': 'gcc -shared -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+             '-Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs '
+             '-flto=auto -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+             '-Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs '
+             '-flto=auto',
  'LDVERSION': '3.9',
  'LIBC': '',
  'LIBDEST': '/usr/lib/python3.9',
@@ -601,7 +618,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/share/man',
- 'MKDIR_P': '/usr/bin/mkdir -p',
+ 'MKDIR_P': '/usr/sbin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
                    '_operator  _collections  _abc  itertools  atexit  _signal  '
                    '_stat  time  _thread  _locale  _io  faulthandler  '
@@ -649,7 +666,7 @@ build_time_vars = {'ABIFLAGS': '',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
  'PROFILE_TASK': '-m test --pgo',
  'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
- 'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
+ 'PTHREAD_SYSTEM_SCHED_SUPPORTED': 0,
  'PURIFY': '',
  'PY3LIBRARY': 'libpython3.so',
  'PYLONG_BITS_IN_DIGIT': 0,
@@ -666,112 +683,140 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
                              '-fwrapv -O3 -Wall -march=x86-64 -mtune=generic '
                              '-O2 -pipe -fno-plt -fexceptions         '
-                             '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                             '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                              '-Werror=format-security         '
-                             '-fstack-clash-protection -fcf-protection -g '
-                             '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
-                             '-fno-semantic-interposition -march=x86-64 '
-                             '-mtune=generic -O2 -pipe -fno-plt '
-                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fstack-clash-protection -fcf-protection         '
+                             '-fno-omit-frame-pointer '
+                             '-mno-omit-leaf-frame-pointer -g '
+                             '-ffile-prefix-map=/home/aurutils/.cache/aurutils/sync/python39/src=/usr/src/debug/python39 '
+                             '-flto=auto -fno-semantic-interposition '
+                             '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
+                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -fcf-protection -g '
-                             '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
-                             '-fno-semantic-interposition -march=x86-64 '
-                             '-mtune=generic -O2 -pipe -fno-plt '
-                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fstack-clash-protection -fcf-protection         '
+                             '-fno-omit-frame-pointer '
+                             '-mno-omit-leaf-frame-pointer -g '
+                             '-ffile-prefix-map=/home/aurutils/.cache/aurutils/sync/python39/src=/usr/src/debug/python39 '
+                             '-flto=auto -fno-semantic-interposition '
+                             '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
+                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -fcf-protection -g '
-                             '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
-                             '-fno-semantic-interposition -flto '
+                             '-fstack-clash-protection -fcf-protection         '
+                             '-fno-omit-frame-pointer '
+                             '-mno-omit-leaf-frame-pointer -g '
+                             '-ffile-prefix-map=/home/aurutils/.cache/aurutils/sync/python39/src=/usr/src/debug/python39 '
+                             '-flto=auto -fno-semantic-interposition -flto '
                              '-fuse-linker-plugin -ffat-lto-objects '
                              '-flto-partition=none -g -std=c99 -Wextra '
                              '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
+                             '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
                              '-I./Include -fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
               '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
-              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
               '-Werror=format-security         -fstack-clash-protection '
-              '-fcf-protection -g '
-              '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
-              '-fno-semantic-interposition -march=x86-64 -mtune=generic -O2 '
-              '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
-              '-Wformat -Werror=format-security         '
-              '-fstack-clash-protection -fcf-protection -g '
-              '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
-              '-fno-semantic-interposition -march=x86-64 -mtune=generic -O2 '
-              '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
-              '-Wformat -Werror=format-security         '
-              '-fstack-clash-protection -fcf-protection -g '
-              '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
-              '-fno-semantic-interposition',
+              '-fcf-protection         -fno-omit-frame-pointer '
+              '-mno-omit-leaf-frame-pointer -g '
+              '-ffile-prefix-map=/home/aurutils/.cache/aurutils/sync/python39/src=/usr/src/debug/python39 '
+              '-flto=auto -fno-semantic-interposition -march=x86-64 '
+              '-mtune=generic -O2 -pipe -fno-plt -fexceptions         '
+              '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+              '-Werror=format-security         -fstack-clash-protection '
+              '-fcf-protection         -fno-omit-frame-pointer '
+              '-mno-omit-leaf-frame-pointer -g '
+              '-ffile-prefix-map=/home/aurutils/.cache/aurutils/sync/python39/src=/usr/src/debug/python39 '
+              '-flto=auto -fno-semantic-interposition -march=x86-64 '
+              '-mtune=generic -O2 -pipe -fno-plt -fexceptions         '
+              '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+              '-Werror=format-security         -fstack-clash-protection '
+              '-fcf-protection         -fno-omit-frame-pointer '
+              '-mno-omit-leaf-frame-pointer -g '
+              '-ffile-prefix-map=/home/aurutils/.cache/aurutils/sync/python39/src=/usr/src/debug/python39 '
+              '-flto=auto -fno-semantic-interposition',
  'PY_CFLAGS_NODIST': '-flto -fuse-linker-plugin -ffat-lto-objects '
                      '-flto-partition=none -g -std=c99 -Wextra '
                      '-Wno-unused-result -Wno-unused-parameter '
-                     '-Wno-missing-field-initializers '
+                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
                    '-Wall -march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
-                   '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-fcf-protection -g '
-                   '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
-                   '-fno-semantic-interposition -march=x86-64 -mtune=generic '
-                   '-O2 -pipe -fno-plt -fexceptions         '
-                   '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-fcf-protection         -fno-omit-frame-pointer '
+                   '-mno-omit-leaf-frame-pointer -g '
+                   '-ffile-prefix-map=/home/aurutils/.cache/aurutils/sync/python39/src=/usr/src/debug/python39 '
+                   '-flto=auto -fno-semantic-interposition -march=x86-64 '
+                   '-mtune=generic -O2 -pipe -fno-plt -fexceptions         '
+                   '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-fcf-protection -g '
-                   '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
-                   '-fno-semantic-interposition -march=x86-64 -mtune=generic '
-                   '-O2 -pipe -fno-plt -fexceptions         '
-                   '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-fcf-protection         -fno-omit-frame-pointer '
+                   '-mno-omit-leaf-frame-pointer -g '
+                   '-ffile-prefix-map=/home/aurutils/.cache/aurutils/sync/python39/src=/usr/src/debug/python39 '
+                   '-flto=auto -fno-semantic-interposition -march=x86-64 '
+                   '-mtune=generic -O2 -pipe -fno-plt -fexceptions         '
+                   '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-fcf-protection -g '
-                   '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
-                   '-fno-semantic-interposition -flto -fuse-linker-plugin '
-                   '-ffat-lto-objects -flto-partition=none -g -std=c99 -Wextra '
-                   '-Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers '
-                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
-                   '-I./Include/internal -I. -I./Include -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-                    '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -flto '
+                   '-fcf-protection         -fno-omit-frame-pointer '
+                   '-mno-omit-leaf-frame-pointer -g '
+                   '-ffile-prefix-map=/home/aurutils/.cache/aurutils/sync/python39/src=/usr/src/debug/python39 '
+                   '-flto=auto -fno-semantic-interposition -flto '
+                   '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none '
+                   '-g -std=c99 -Wextra -Wno-unused-result '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
+                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+                   '-fPIC -DPy_BUILD_CORE',
+ 'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+                    '-Wl,-z,now          -Wl,-z,pack-relative-relocs '
+                    '-flto=auto -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+                    '-Wl,-z,relro -Wl,-z,now          '
+                    '-Wl,-z,pack-relative-relocs -flto=auto -flto '
                     '-fuse-linker-plugin -ffat-lto-objects '
                     '-flto-partition=none -g',
  'PY_CPPFLAGS': '-I. -I./Include',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-               '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'PY_LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+               '-Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto '
+               '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+               '-Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto',
  'PY_LDFLAGS_NODIST': '-flto -fuse-linker-plugin -ffat-lto-objects '
                       '-flto-partition=none -g',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
                         '-O3 -Wall -march=x86-64 -mtune=generic -O2 -pipe '
-                        '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+                        '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
                         '-Wformat -Werror=format-security         '
-                        '-fstack-clash-protection -fcf-protection -g '
-                        '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
-                        '-fno-semantic-interposition -march=x86-64 '
+                        '-fstack-clash-protection -fcf-protection         '
+                        '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
+                        '-g '
+                        '-ffile-prefix-map=/home/aurutils/.cache/aurutils/sync/python39/src=/usr/src/debug/python39 '
+                        '-flto=auto -fno-semantic-interposition -march=x86-64 '
                         '-mtune=generic -O2 -pipe -fno-plt '
-                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                         '-Werror=format-security         '
-                        '-fstack-clash-protection -fcf-protection -g '
-                        '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
-                        '-fno-semantic-interposition -march=x86-64 '
+                        '-fstack-clash-protection -fcf-protection         '
+                        '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
+                        '-g '
+                        '-ffile-prefix-map=/home/aurutils/.cache/aurutils/sync/python39/src=/usr/src/debug/python39 '
+                        '-flto=auto -fno-semantic-interposition -march=x86-64 '
                         '-mtune=generic -O2 -pipe -fno-plt '
-                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                         '-Werror=format-security         '
-                        '-fstack-clash-protection -fcf-protection -g '
-                        '-ffile-prefix-map=/build/python39/src=/usr/src/debug/python39 '
-                        '-fno-semantic-interposition -flto -fuse-linker-plugin '
-                        '-ffat-lto-objects -flto-partition=none -g -std=c99 '
-                        '-Wextra -Wno-unused-result -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers '
+                        '-fstack-clash-protection -fcf-protection         '
+                        '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer '
+                        '-g '
+                        '-ffile-prefix-map=/home/aurutils/.cache/aurutils/sync/python39/src=/usr/src/debug/python39 '
+                        '-flto=auto -fno-semantic-interposition -flto '
+                        '-fuse-linker-plugin -ffat-lto-objects '
+                        '-flto-partition=none -g -std=c99 -Wextra '
+                        '-Wno-unused-result -Wno-unused-parameter '
+                        '-Wno-missing-field-initializers -Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include -fPIC',
@@ -783,7 +828,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python39/src/Python-3.9.19',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/home/aurutils/.cache/aurutils/sync/python39/src/Python-3.9.23',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -824,10 +869,11 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python39/src/Python-3.9.19 ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/aurutils/.cache/aurutils/sync/python39/src/Python-3.9.23 '
+               './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python39/src/Python-3.9.19 ./python '
-               './Tools/scripts/run_tests.py',
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/home/aurutils/.cache/aurutils/sync/python39/src/Python-3.9.23 '
+               './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
@@ -838,7 +884,7 @@ build_time_vars = {'ABIFLAGS': '',
  'UPDATE_FILE': 'python3 ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
  'VERSION': '3.9',
- 'WINDOW_HAS_FLAGS': 1,
+ 'WINDOW_HAS_FLAGS': 0,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
@@ -849,8 +895,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python39/src/Python-3.9.19',
- 'abs_srcdir': '/build/python39/src/Python-3.9.19',
+ 'abs_builddir': '/home/aurutils/.cache/aurutils/sync/python39/src/Python-3.9.23',
+ 'abs_srcdir': '/home/aurutils/.cache/aurutils/sync/python39/src/Python-3.9.23',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
